#ifndef SRC_DELETE_DIR_DAEMON_H_
#define SRC_DELETE_DIR_DAEMON_H_

#include <stddef.h>

int delete_dir_daemon_start(char **, size_t, char const *);

#endif /* SRC_DELETE_DIR_DAEMON_H_ */
